==> lhcsmapi-1.3.229.tar.gz: lhcsmapi-1.3.229/test/test_gui/test_600AFgcPmSearchBaseModule.py <==
import unittest

from lhcsmapi.gui.pc.R600AFgcPmSearchBaseModule import combine_coupled_fgc_pm_entries, \
    _convert_fgc_pm_entries_to_options


class Test_600ARcbxhvFgcPmSearchBaseModule(unittest.TestCase):

    def test_find_coupled_fgc_pm_entries_rcbx(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000),
                          ('RCBXH1.R1', 1493219269240000000),
                          ('RCBXV1.R1', 1493238314340000000),
                          ('RCBXH1.R1', 1493238314400000000)]

        # act
        compacted_fgc_pm_entries_act = combine_coupled_fgc_pm_entries(fgc_pm_entries,
                                                                      circuit_prefixes=['RCBXH', 'RCBXV'])

        # assert
        compacted_fgc_pm_entries_ref = [('RCBXV1.R1', 1493219269220000000, 'RCBXH1.R1', 1493219269240000000),
                                        ('RCBXV1.R1', 1493238314340000000, 'RCBXH1.R1', 1493238314400000000)]

        self.assertListEqual(compacted_fgc_pm_entries_ref, compacted_fgc_pm_entries_act)

    def test_find_coupled_fgc_pm_entries_rcbx_mixed(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000),
                          ('RCBXH1.R1', 1593219269240000000),
                          ('RCBXV1.R1', 1493238314340000000),
                          ('RCBXH1.R1', 1493238314400000000)]

        # act
        compacted_fgc_pm_entries_act = combine_coupled_fgc_pm_entries(fgc_pm_entries,
                                                                      circuit_prefixes=['RCBXH', 'RCBXV'])

        # assert
        compacted_fgc_pm_entries_ref = [('RCBXV1.R1', 1493219269220000000),
                                        ('RCBXH1.R1', 1593219269240000000),
                                        ('RCBXV1.R1', 1493238314340000000, 'RCBXH1.R1', 1493238314400000000)]

        self.assertListEqual(compacted_fgc_pm_entries_ref, compacted_fgc_pm_entries_act)

    def test_find_coupled_fgc_pm_entries_rcbx_different_names(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000),
                          ('RCBXH2.R1', 1593219269240000000),
                          ('RCBXV1.R1', 1493238314340000000),
                          ('RCBXH2.R1', 1493238314400000000)]

        # act
        compacted_fgc_pm_entries_act = combine_coupled_fgc_pm_entries(fgc_pm_entries,
                                                                      circuit_prefixes=['RCBXH', 'RCBXV'])

        # assert
        compacted_fgc_pm_entries_ref = [('RCBXV1.R1', 1493219269220000000),
                                        ('RCBXH2.R1', 1593219269240000000),
                                        ('RCBXV1.R1', 1493238314340000000),
                                        ('RCBXH2.R1', 1493238314400000000)]

        self.assertListEqual(compacted_fgc_pm_entries_ref, compacted_fgc_pm_entries_act)

    def test_convert_fgc_pm_entries_to_options_single(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000),
                          ('RCBXV1.R1', 1493238314340000000)]

        # act
        options_act = _convert_fgc_pm_entries_to_options(fgc_pm_entries)

        # assert
        options_ref = ['RCBXV1.R1: 2017-04-26 17:07:49.220000+02:00',
                       'RCBXV1.R1: 2017-04-26 22:25:14.340000+02:00']
        self.assertListEqual(options_ref, options_act)

    def test_convert_fgc_pm_entries_to_options_double(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000, 'RCBXH1.R1', 1493219269240000000),
                          ('RCBXV1.R1', 1493238314340000000, 'RCBXH1.R1', 1493238314400000000)]

        # act
        options_act = _convert_fgc_pm_entries_to_options(fgc_pm_entries)

        # assert
        options_ref = ['RCBXV1.R1: 2017-04-26 17:07:49.220000+02:00; RCBXH1.R1: 2017-04-26 17:07:49.240000+02:00',
                       'RCBXV1.R1: 2017-04-26 22:25:14.340000+02:00; RCBXH1.R1: 2017-04-26 22:25:14.400000+02:00']
        self.assertListEqual(options_ref, options_act)

==> lhcsmapi-1.4.58.tar.gz: lhcsmapi-1.4.58/test/test_gui/test_600AFgcPmSearchBaseModule.py <==
import unittest

from lhcsmapi.gui.pc.R600AFgcPmSearchBaseModule import combine_coupled_fgc_pm_entries, R600AFgcPmSearchBaseModule


class Test_600ARcbxhvFgcPmSearchBaseModule(unittest.TestCase):

    def test_find_coupled_fgc_pm_entries_rcbx(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000),
                          ('RCBXH1.R1', 1493219269240000000),
                          ('RCBXV1.R1', 1493238314340000000),
                          ('RCBXH1.R1', 1493238314400000000)]

        # act
        compacted_fgc_pm_entries_act = combine_coupled_fgc_pm_entries(fgc_pm_entries,
                                                                      circuit_prefixes=['RCBXH', 'RCBXV'])

        # assert
        compacted_fgc_pm_entries_ref = [('RCBXV1.R1', 1493219269220000000, 'RCBXH1.R1', 1493219269240000000),
                                        ('RCBXV1.R1', 1493238314340000000, 'RCBXH1.R1', 1493238314400000000)]

        self.assertListEqual(compacted_fgc_pm_entries_ref, compacted_fgc_pm_entries_act)

    def test_find_coupled_fgc_pm_entries_rcbx_mixed(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000),
                          ('RCBXH1.R1', 1593219269240000000),
                          ('RCBXV1.R1', 1493238314340000000),
                          ('RCBXH1.R1', 1493238314400000000)]

        # act
        compacted_fgc_pm_entries_act = combine_coupled_fgc_pm_entries(fgc_pm_entries,
                                                                      circuit_prefixes=['RCBXH', 'RCBXV'])

        # assert
        compacted_fgc_pm_entries_ref = [('RCBXV1.R1', 1493219269220000000),
                                        ('RCBXH1.R1', 1593219269240000000),
                                        ('RCBXV1.R1', 1493238314340000000, 'RCBXH1.R1', 1493238314400000000)]

        self.assertListEqual(compacted_fgc_pm_entries_ref, compacted_fgc_pm_entries_act)

    def test_find_coupled_fgc_pm_entries_rcbx_different_names(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000),
                          ('RCBXH2.R1', 1593219269240000000),
                          ('RCBXV1.R1', 1493238314340000000),
                          ('RCBXH2.R1', 1493238314400000000)]

        # act
        compacted_fgc_pm_entries_act = combine_coupled_fgc_pm_entries(fgc_pm_entries,
                                                                      circuit_prefixes=['RCBXH', 'RCBXV'])

        # assert
        compacted_fgc_pm_entries_ref = [('RCBXV1.R1', 1493219269220000000),
                                        ('RCBXH2.R1', 1593219269240000000),
                                        ('RCBXV1.R1', 1493238314340000000),
                                        ('RCBXH2.R1', 1493238314400000000)]

        self.assertListEqual(compacted_fgc_pm_entries_ref, compacted_fgc_pm_entries_act)

    def test_convert_fgc_pm_entries_to_options_single(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000),
                          ('RCBXV1.R1', 1493238314340000000)]

        # act
        options_act = R600AFgcPmSearchBaseModule().convert_fgc_pm_entries_to_options(fgc_pm_entries)

        # assert
        options_ref = ['RCBXV1.R1: 2017-04-26 17:07:49.220000+02:00',
                       'RCBXV1.R1: 2017-04-26 22:25:14.340000+02:00']
        self.assertListEqual(options_ref, options_act)

    def test_convert_fgc_pm_entries_to_options_double(self):
        # arrange
        fgc_pm_entries = [('RCBXV1.R1', 1493219269220000000, 'RCBXH1.R1', 1493219269240000000),
                          ('RCBXV1.R1', 1493238314340000000, 'RCBXH1.R1', 1493238314400000000)]

        # act
        options_act = R600AFgcPmSearchBaseModule().convert_fgc_pm_entries_to_options(fgc_pm_entries)

        # assert
        options_ref = ['RCBXV1.R1: 2017-04-26 17:07:49.220000+02:00; RCBXH1.R1: 2017-04-26 17:07:49.240000+02:00',
                       'RCBXV1.R1: 2017-04-26 22:25:14.340000+02:00; RCBXH1.R1: 2017-04-26 22:25:14.400000+02:00']
        self.assertListEqual(options_ref, options_act)
